@@ -85,26 +85,12 @@ L<Crypt::Sodium::XS::ProtMem/protmem_flags_memvault_default>).
 
 =head1 METHODS
 
-=head2 is_locked
-
-  my $is_locked = $mv->is_locked;
-
-Returns a boolean indicating if the object is conceptually "locked."
-
 =head2 clone
 
   my $new_mv = $mv->clone;
 
 Returns a new object C<$new_mv> with identical contents to the original C<$mv>.
 
-=head2 concat
-
-  my $new_mv = $mv->concat($bytes);
-  my $new_mv = $mv->concat($other_mv);
-
-Returns a new object with the concatenated contents of C<$mv> followed by
-C<$bytes> or the contents of C<$other_mv>.
-
 =head2 compare
 
   $mv->compare($bytes, $length);
@@ -118,6 +104,14 @@ Comparible to the C<cmp> perl operator.
 C<$length> is optional iif C<$mv> and C<$other_mv> (or C<$bytes>) are equal
 lengths. If provided, only C<$length> bytes are compared.
 
+=head2 concat
+
+  my $new_mv = $mv->concat($bytes);
+  my $new_mv = $mv->concat($other_mv);
+
+Returns a new object with the concatenated contents of C<$mv> followed by
+C<$bytes> or the contents of C<$other_mv>.
+
 =head2 flags
 
   my $flags = $mv->flags;
@@ -128,35 +122,18 @@ L<Crypt::Sodium::XS::ProtMem/MEMORY SAFETY>.
 
 =head2 from_base64
 
-  # shortcut for Crypt::Sodium::XS::MemVault->new_from_base64($mv, ..);
-  my $new_mv = $mv->from_base64($variant, $flags);
-
-C<$variant> is optional (default:
-L<Crypt::Sodium::XS::Base64/BASE64_VARIANT_URLSAFE_NO_PADDING>). See
-L<Crypt::Sodium::XS::BASE64/CONSTANTS>.
-
-C<$flags> is optional. If not provided, the new MemVault will use the same
-flags as the one from which it is created.
-
-Stops parsing at the first non-base64 byte (valid characters depend on
-C<$variant>). C<$new_mv> will be empty if the data cannot be parsed as valid
-base64 (i.e., the output would not be a multiple of 8 bits).
+Shortcut for L<Crypt::Sodium::XS::MemVault/new_from_base64>.
 
 =head2 from_hex
 
-  # shortcut for Crypt::Sodium::XS::MemVault->new_from_hex($mv, ..);
-  my $new_mv = $mv->from_hex($flags);
-
-C<$flags> is optional. If not provided, the new MemVault will use the same
-flags as the one from which it is created.
-
-Stops parsing at the first non-hex ([0-9a-f] case insensitive) byte.
+Shortcut for L<Crypt::Sodium::XS::MemVault/new_from_hex>.
 
 =head2 index
 
-  my $pos = $mv->index($substr, $offset);
+B<!!WARNING!!>: This method does not run in constant-time and may leak
+information about the protected memory.
 
-B<WARNING>: this method does B<NOT> run in constant-time!
+  my $pos = $mv->index($substr, $offset);
 
 Searches for an occurence of C<$substr> in protected memory. This is similar to
 perl's own index function. Returns the first match of C<$substr> at or after
@@ -170,6 +147,12 @@ protected memory.
 This method should only be used when protected memory starts with non-sensitive
 data, and is guaranteed to find C<$substr> before any sensitive data.
 
+=head2 is_locked
+
+  my $is_locked = $mv->is_locked;
+
+Returns a boolean indicating if the object is conceptually "locked."
+
 =head2 is_zero
 
   my $is_null = $mv->is_zero;
